==> haskell-gi-0.26.15-22.1-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-gi.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                   haskell-gi
version:                0.26.15
visibility:             public
id:                     haskell-gi-0.26.15-AARHkARXvviJnUvBU75LBO
key:                    haskell-gi-0.26.15-AARHkARXvviJnUvBU75LBO
license:                LGPL-2.1-only
maintainer:             Iñaki García Etxebarria (github@the.blueleaf.cc)
author:                 Will Thompson and Iñaki García Etxebarria
stability:              Experimental
homepage:               https://github.com/haskell-gi/haskell-gi
synopsis:
    Generate Haskell bindings for GObject Introspection capable libraries

description:
    Generate Haskell bindings for GObject Introspection capable libraries. This includes most notably
    GTK, but many other libraries in the GObject ecosystem provide introspection data too.

category:               Development
abi:                    7bb411a3f54273b18e7f4f76461e72de
exposed:                True
exposed-modules:
    Data.GI.CodeGen.API Data.GI.CodeGen.CabalHooks
    Data.GI.CodeGen.Callable Data.GI.CodeGen.Code
    Data.GI.CodeGen.CodeGen Data.GI.CodeGen.Config
    Data.GI.CodeGen.Constant Data.GI.CodeGen.Conversions
    Data.GI.CodeGen.CtoHaskellMap Data.GI.CodeGen.EnumFlags
    Data.GI.CodeGen.Fixups Data.GI.CodeGen.GObject
    Data.GI.CodeGen.GType Data.GI.CodeGen.GtkDoc
    Data.GI.CodeGen.Haddock Data.GI.CodeGen.Inheritance
    Data.GI.CodeGen.LibGIRepository Data.GI.CodeGen.ModulePath
    Data.GI.CodeGen.OverloadedMethods Data.GI.CodeGen.OverloadedSignals
    Data.GI.CodeGen.Overrides Data.GI.CodeGen.PkgConfig
    Data.GI.CodeGen.ProjectInfo Data.GI.CodeGen.Properties
    Data.GI.CodeGen.Signal Data.GI.CodeGen.Struct
    Data.GI.CodeGen.SymbolNaming Data.GI.CodeGen.Transfer
    Data.GI.CodeGen.Type Data.GI.CodeGen.Util Data.GI.GIR.Alias
    Data.GI.GIR.Allocation Data.GI.GIR.Arg Data.GI.GIR.BasicTypes
    Data.GI.GIR.Callable Data.GI.GIR.Callback Data.GI.GIR.Constant
    Data.GI.GIR.Deprecation Data.GI.GIR.Documentation Data.GI.GIR.Enum
    Data.GI.GIR.Field Data.GI.GIR.Flags Data.GI.GIR.Function
    Data.GI.GIR.Interface Data.GI.GIR.Method Data.GI.GIR.Object
    Data.GI.GIR.Parser Data.GI.GIR.Property Data.GI.GIR.Repository
    Data.GI.GIR.Signal Data.GI.GIR.Struct Data.GI.GIR.Type
    Data.GI.GIR.Union Data.GI.GIR.XMLUtils

hidden-modules:         Paths_haskell_gi
import-dirs:            /usr/lib/ghc-9.6.6/site-local/haskell-gi-0.26.15
library-dirs:
    /usr/lib/ghc-9.6.6/site-local/haskell-gi-0.26.15 /usr/lib

library-dirs-static:
    /usr/lib/ghc-9.6.6/site-local/haskell-gi-0.26.15 /usr/lib

dynamic-library-dirs:   /usr/lib /usr/lib
data-dir:               /usr/share/haskell-gi
hs-libraries:           HShaskell-gi-0.26.15-AARHkARXvviJnUvBU75LBO
extra-libraries:        girepository-1.0 gobject-2.0 glib-2.0
extra-libraries-static:
    girepository-1.0 gobject-2.0 glib-2.0 m sysprof-capture-4 pcre2-8
    pthread ffi

include-dirs:
    /usr/include/gobject-introspection-1.0 /usr/include
    /usr/include/glib-2.0 /usr/lib/glib-2.0/include
    /usr/include/sysprof-6

depends:
    Cabal-3.10.3.0 ansi-terminal-1.0.2-99kMoKqjfKvAwKECL4LpDt
    attoparsec-0.14.4-8gkbEkDkw506qTMOo0v2nm base-4.18.2.1
    bytestring-0.11.5.3 containers-0.6.7 directory-1.3.8.5
    filepath-1.4.300.1 haskell-gi-base-0.26.9-9dGlnSJnubc2h9MiqHeprA
    mtl-2.3.1 pretty-show-1.10-EXsS4VwIV5tJ56gbmVdfrR process-1.6.19.0
    regex-tdfa-1.3.2.5-ATqtlBuPETHJOcVIKuiav2
    safe-0.3.21-6ywRAlXnRFuBscoqJeUz3o text-2.0.2 transformers-0.6.1.0
    xdg-basedir-0.2.2-DLaKUfv1JJAFBfkP0BUklH
    xml-conduit-1.9.1.4-1cCl4mnX5as2ZihXQ5w8FO

haddock-interfaces:     /usr/share/doc/haskell-gi/html/haskell-gi.haddock
haddock-html:           /usr/share/doc/haskell-gi/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-gi-0.26.16-2-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-gi.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                   haskell-gi
version:                0.26.16
visibility:             public
id:                     haskell-gi-0.26.16-DRMB6Y9Bskv7maGoKfpb8b
key:                    haskell-gi-0.26.16-DRMB6Y9Bskv7maGoKfpb8b
license:                LGPL-2.1-only
maintainer:             Iñaki García Etxebarria (github@the.blueleaf.cc)
author:                 Will Thompson and Iñaki García Etxebarria
stability:              Experimental
homepage:               https://github.com/haskell-gi/haskell-gi
synopsis:
    Generate Haskell bindings for GObject Introspection capable libraries

description:
    Generate Haskell bindings for GObject Introspection capable libraries. This includes most notably
    GTK, but many other libraries in the GObject ecosystem provide introspection data too.

category:               Development
abi:                    5e18312b3b31851884c57f07f1c6c1dd
exposed:                True
exposed-modules:
    Data.GI.CodeGen.API Data.GI.CodeGen.CabalHooks
    Data.GI.CodeGen.Callable Data.GI.CodeGen.Code
    Data.GI.CodeGen.CodeGen Data.GI.CodeGen.Config
    Data.GI.CodeGen.Constant Data.GI.CodeGen.Conversions
    Data.GI.CodeGen.CtoHaskellMap Data.GI.CodeGen.EnumFlags
    Data.GI.CodeGen.Fixups Data.GI.CodeGen.GObject
    Data.GI.CodeGen.GType Data.GI.CodeGen.GtkDoc
    Data.GI.CodeGen.Haddock Data.GI.CodeGen.Inheritance
    Data.GI.CodeGen.LibGIRepository Data.GI.CodeGen.ModulePath
    Data.GI.CodeGen.OverloadedMethods Data.GI.CodeGen.OverloadedSignals
    Data.GI.CodeGen.Overrides Data.GI.CodeGen.PkgConfig
    Data.GI.CodeGen.ProjectInfo Data.GI.CodeGen.Properties
    Data.GI.CodeGen.Signal Data.GI.CodeGen.Struct
    Data.GI.CodeGen.SymbolNaming Data.GI.CodeGen.Transfer
    Data.GI.CodeGen.Type Data.GI.CodeGen.Util Data.GI.GIR.Alias
    Data.GI.GIR.Allocation Data.GI.GIR.Arg Data.GI.GIR.BasicTypes
    Data.GI.GIR.Callable Data.GI.GIR.Callback Data.GI.GIR.Constant
    Data.GI.GIR.Deprecation Data.GI.GIR.Documentation Data.GI.GIR.Enum
    Data.GI.GIR.Field Data.GI.GIR.Flags Data.GI.GIR.Function
    Data.GI.GIR.Interface Data.GI.GIR.Method Data.GI.GIR.Object
    Data.GI.GIR.Parser Data.GI.GIR.Property Data.GI.GIR.Repository
    Data.GI.GIR.Signal Data.GI.GIR.Struct Data.GI.GIR.Type
    Data.GI.GIR.Union Data.GI.GIR.XMLUtils

hidden-modules:         Paths_haskell_gi
import-dirs:            /usr/lib/ghc-9.6.6/site-local/haskell-gi-0.26.16
library-dirs:
    /usr/lib/ghc-9.6.6/site-local/haskell-gi-0.26.16 /usr/lib

library-dirs-static:
    /usr/lib/ghc-9.6.6/site-local/haskell-gi-0.26.16 /usr/lib

dynamic-library-dirs:   /usr/lib /usr/lib
data-dir:               /usr/share/haskell-gi
hs-libraries:           HShaskell-gi-0.26.16-DRMB6Y9Bskv7maGoKfpb8b
extra-libraries:        girepository-1.0 gobject-2.0 glib-2.0
extra-libraries-static:
    girepository-1.0 gobject-2.0 glib-2.0 m sysprof-capture-4 pcre2-8
    pthread ffi

include-dirs:
    /usr/include/gobject-introspection-1.0 /usr/include
    /usr/include/glib-2.0 /usr/lib/glib-2.0/include
    /usr/include/sysprof-6

depends:
    Cabal-3.10.3.0 ansi-terminal-1.0.2-99kMoKqjfKvAwKECL4LpDt
    attoparsec-0.14.4-8gkbEkDkw506qTMOo0v2nm base-4.18.2.1
    bytestring-0.11.5.3 containers-0.6.7 directory-1.3.8.5
    filepath-1.4.300.1 haskell-gi-base-0.26.9-9dGlnSJnubc2h9MiqHeprA
    mtl-2.3.1 pretty-show-1.10-EXsS4VwIV5tJ56gbmVdfrR process-1.6.19.0
    regex-tdfa-1.3.2.5-ATqtlBuPETHJOcVIKuiav2
    safe-0.3.21-6ywRAlXnRFuBscoqJeUz3o text-2.0.2 transformers-0.6.1.0
    xdg-basedir-0.2.2-DLaKUfv1JJAFBfkP0BUklH
    xml-conduit-1.9.1.4-4ApAZ67Z6lCGy52B3tehMj

haddock-interfaces:     /usr/share/doc/haskell-gi/html/haskell-gi.haddock
haddock-html:           /usr/share/doc/haskell-gi/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
